@@ -1,9 +1,13 @@
+#' @importFrom stats as.formula fitted lm na.omit pchisq pnorm predict qnorm rbinom rnorm runif terms vcov
+#'
+NULL
+
 #' Fit cosinor model
 #'
 #' Given an outcome and time variable, fit the cosinor model with optional
 #' covariate effects.
 #'
-#' @param formula Forumla specifying the model. Indicate the time variable with
+#' @param formula Formula specifying the model. Indicate the time variable with
 #'   \code{time()} and covariate effects on the amplitude and acrophase with
 #'   \code{amp.acro()}. See details for more information.
 #' @param period Length of time for a complete period of the sine curve.
@@ -15,7 +19,7 @@
 #'   indicate the time variable wrap the name of it in the function
 #'   \code{time()}. To indicate a variable which affects the
 #'   acrophase/amplitude, wrap the name in \code{amp.acro()}. This will then do
-#'   all the tranformations for you. See examples for usage.
+#'   all the transformations for you. See examples for usage.
 #'
 #' @examples
 #'
@@ -40,8 +44,8 @@ cosinor.lm <- function(formula, period = 12,
   varnames <- get_varnames(Terms)
   timevar <- varnames[attr(Terms, "specials")$time - 1]
 
-  data$rrr <- cos(2 * pi * data[,timevar] / period)
-  data$sss <- sin(2 * pi * data[,timevar] / period)
+  data$rrr <- cos(2 * pi * data[[timevar]] / period)
+  data$sss <- sin(2 * pi * data[[timevar]] / period)
 
   spec_dex <- unlist(attr(Terms, "special")$amp.acro) - 1
   mainpart <- c(varnames[c(-spec_dex, - (attr(Terms, "special")$time - 1))], "rrr", "sss")
@@ -112,7 +116,7 @@ print.cosinor.lm <- function(x, ...){
 #' @details This defines special functions that are used in the formula to indicate the time variable
 #' and which covariates effect the amplitude. To indicate the time variable wrap the name of it in the function
 #' \code{time()}. To indicate a variable which affects the acrophase/amplitude, wrap the name in
-#' \code{amp.acro()}. This will then do all the tranformations for you. See examples for usage.
+#' \code{amp.acro()}. This will then do all the transformations for you. See examples for usage.
 #'
 #' @examples
 #'
